@@ -49,9 +49,9 @@
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 
-#include <exif-data.h>
-#include <exif-content.h>
-#include <exif-entry.h>
+#include <libexif/exif-data.h>
+#include <libexif/exif-content.h>
+#include <libexif/exif-entry.h>
 
 #define BUFFER_SIZE 8192
 
@@ -329,6 +329,26 @@ f_get_jpeg_size  (const char *path,
 }
 
 
+void
+f_save_jpeg_exif (const char *filename, ExifData *exif_data)
+{
+	JPEGData     *jdata;
+
+	g_warning ("exif = %p", exif_data);
+	jdata = jpeg_data_new_from_file (filename);
+	if (jdata == NULL) {
+		g_warning ("unable to parse jpeg file");
+		return;
+	}
+	if (exif_data == NULL) {
+		g_warning ("missing exif data");
+	}
+	jpeg_data_set_exif_data (jdata, exif_data);
+	jpeg_data_save_file (jdata, filename);
+
+	jpeg_data_unref (jdata);
+}
+
 /* Implementation of non-lossy JPEG file transformations, based on GThumb code
    by Paolo Bacchilega.  */
 
@@ -443,7 +463,7 @@ f_transform_jpeg  (const char      *source_path,
 		jpegtran_transform = JXFORM_FLIP_V;
 		break;
 	default:
-		g_warning (G_GNUC_FUNCTION ": unknown transform type %d", transform);
+		g_warning ("%s(): unknown transform type %d", G_STRFUNC, transform);
 		if (error_message_return != NULL)
 			*error_message_return = g_strdup_printf (_("Unknown transform type %d"), transform);
 		return FALSE;
