@@ -6,11 +6,13 @@
  *
  * Copyright (c) 2004 Novell, Inc.
  *
- *
+ * This is free software. See COPYING for details.
  */
 
 using System;
 using Mono.Unix;
+using FSpot;
+using FSpot.Utils;
 
 public class TagPopup {
 	public void Activate (Gdk.EventButton eb, Tag tag, Tag [] tags)
@@ -27,7 +29,7 @@ public class TagPopup {
                 true
         );
 
-        FSpot.Query.TermMenuItem.Create (tags, popup_menu);
+        FSpot.TermMenuItem.Create (tags, popup_menu);
 
 		GtkUtil.MakeMenuSeparator (popup_menu);
 		
